==> mozc-1.3.931.102.tar.bz2: mozc-1.3.931.102/rewriter/remove_redundant_candidate_rewriter.cc <==
// Copyright 2010-2011, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#include "rewriter/remove_redundant_candidate_rewriter.h"

#include "base/base.h"
#include "converter/segments.h"

namespace mozc {

RemoveRedundantCandidateRewriter::RemoveRedundantCandidateRewriter() {}

RemoveRedundantCandidateRewriter::~RemoveRedundantCandidateRewriter() {}

int RemoveRedundantCandidateRewriter::capability() const {
  return RewriterInterface::NOT_AVAILABLE;
}

bool RemoveRedundantCandidateRewriter::Rewrite(Segments *segments) const {
  if (segments->conversion_segments_size() == 1 &&
      segments->conversion_segment(0).candidates_size() == 1 &&
      segments->conversion_segment(0).candidate(0).value ==
      segments->conversion_segment(0).key()) {
    segments->mutable_conversion_segment(0)->clear_candidates();
    return true;
  } else {
    return false;
  }
}
}  // namespace mozc

==> mozc-1.5.1053.102.tar.bz2: mozc-1.5.1053.102/rewriter/remove_redundant_candidate_rewriter.cc <==
// Copyright 2010-2012, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#include "rewriter/remove_redundant_candidate_rewriter.h"

#include "base/base.h"
#include "converter/conversion_request.h"
#include "converter/segments.h"

namespace mozc {

RemoveRedundantCandidateRewriter::RemoveRedundantCandidateRewriter() {}

RemoveRedundantCandidateRewriter::~RemoveRedundantCandidateRewriter() {}

int RemoveRedundantCandidateRewriter::capability() const {
  return RewriterInterface::NOT_AVAILABLE;
}

bool RemoveRedundantCandidateRewriter::Rewrite(const ConversionRequest &request,
                                               Segments *segments) const {
  if (segments->conversion_segments_size() == 1 &&
      segments->conversion_segment(0).candidates_size() == 1 &&
      segments->conversion_segment(0).candidate(0).value ==
      segments->conversion_segment(0).key()) {
    segments->mutable_conversion_segment(0)->clear_candidates();
    return true;
  } else {
    return false;
  }
}
}  // namespace mozc
